==> mudlet_3.2.0.orig.tar.xz: mudlet-3.2.0/src/dlgNotepad.h <==
#ifndef MUDLET_DLGNOTEPAD_H
#define MUDLET_DLGNOTEPAD_H

/***************************************************************************
 *   Copyright (C) 2008-2009 by Heiko Koehn - KoehnHeiko@googlemail.com    *
 *   Copyright (C) 2014 by Ahmed Charles - acharles@outlook.com            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "pre_guard.h"
#include "ui_notes_editor.h"
#include <QPointer>
#include "post_guard.h"

class Host;


class dlgNotepad : public QMainWindow, public Ui::NotesEditor
{
    Q_OBJECT

    Q_DISABLE_COPY(dlgNotepad)

public:
    dlgNotepad(Host*);
    void save();
    void restore();

private:
    QPointer<Host> mpHost;
};

#endif // MUDLET_DLGNOTEPAD_H

==> mudlet_3.5.0.orig.tar.xz: mudlet-3.5.0/src/dlgNotepad.h <==
#ifndef MUDLET_DLGNOTEPAD_H
#define MUDLET_DLGNOTEPAD_H

/***************************************************************************
 *   Copyright (C) 2008-2009 by Heiko Koehn - KoehnHeiko@googlemail.com    *
 *   Copyright (C) 2014 by Ahmed Charles - acharles@outlook.com            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "pre_guard.h"
#include "ui_notes_editor.h"
#include <QPointer>
#include "post_guard.h"

class Host;


class dlgNotepad : public QMainWindow, public Ui::notes_editor
{
    Q_OBJECT

    Q_DISABLE_COPY(dlgNotepad)

public:
    dlgNotepad(Host*);
    void save();
    void restore();

private:
    QPointer<Host> mpHost;
};

#endif // MUDLET_DLGNOTEPAD_H
